import { ComponentType, ButtonHTMLAttributes } from "react";
import { Size, Color } from "../utils/types";
import { IconProps } from "../Icon/props";
export declare type Kind = "decorated" | "solid" | "outline" | "ghost";
export declare type IconPosition = "right" | "left";
export declare type Target = "_blank" | "_self" | "_parent" | "_top" | "framename";
export interface ButtonProps extends ButtonHTMLAttributes<HTMLButtonElement> {
    /**
     * Default: 'decorated' |
     * Specifies design style button with a string.
     */
    kind?: Kind;
    /**
     * Default: 'primary' |
     * Specifies button color with a string.
     */
    color?: Color;
    /**
     * Default: 'normal' |
     * Specifies the button size with a string.
     */
    size?: Size;
    /**
     *Default: false |
     * Makes the button use all available horizontal space.
     */
    block?: boolean;
    /**
     * Default: false |
     * This prop sets the disable html attr as true.
     */
    disabled?: boolean;
    /**
     * Default: false |
     * Specifies if the button has initiated an action and must wait for it (this prop automatically sets the disable html attribute as true).
     */
    loading?: boolean;
    /**
     * Default: 'button' |
     * This is the html element to render, it could be 'a', 'button' or any react component that you need, ex: react router link.
     */
    renderElement?: "button" | "a" | ComponentType<any>;
    /**
     * Default: 'button' |
     * This is the 'type' html attr.
     */
    type?: "submit" | "reset" | "button";
    /**
     * Default: null |
     * You can use this props to send a string with you custom css classes.
     */
    className?: string;
    /**
     * Default: null |
     * Send the inUI icon name, this button will manage it.
     */
    icon?: IconProps["name"];
    /**
     * Default: false |
     * Specifies if the button will only show the icon and not the children react prop, the icon prop must be already set for this action.
     */
    onlyIcon?: boolean;
    /**
     * Default: 'left' |
     * Specifies the icon position in the button, it could be 'right' or 'left'.
     */
    iconPosition?: IconPosition;
    /**
     * Default: 'Icon' |
     * Specifies the icon title in the button.
     */
    iconTitle?: string;
    /**
     * Default: null |
     * Specifies target fot <a> renderElement.
     */
    target?: Target;
    /**
     * Default: null |
     * Specifies href fot <a> renderElement.
     */
    href?: string;
    /**
     * Default: null |
     * Specifies the to attr for link component ex: react router link.
     */
    to?: string;
}
//# sourceMappingURL=props.d.ts.map